@@ -70,6 +70,10 @@ pub const STYLE_CONFIG_DARK_DEFAULT: &str = ".poloto { \
     .poloto6fill{fill:orange;} \
     .poloto7fill{fill:chocolate;}";
 
+pub fn write_header<T: std::fmt::Write>(mut w: T, width: f64, height: f64) -> std::fmt::Result {
+    write!(w,"<svg class=\"poloto\" width=\"{0}\" height=\"{1}\" viewBox=\"0 0 {0} {1}\" xmlns=\"http://www.w3.org/2000/svg\">",width,height)
+}
+
 ///
 /// Create a simple theme.
 ///
@@ -80,10 +84,12 @@ pub trait SimpleTheme {
 
 impl<X: PlotNum, Y: PlotNum> SimpleTheme for Plotter<'_, X, Y> {
     fn simple_theme(&mut self, a: &mut dyn fmt::Write) -> std::fmt::Result {
+        let dim = self.get_dim();
+
         write!(
             a,
             "{}<style>{}</style>{}{}",
-            SVG_HEADER,
+            disp_const(|w| write_header(w, dim[0], dim[1])),
             STYLE_CONFIG_LIGHT_DEFAULT,
             disp(|a| self.render(a)),
             SVG_END
@@ -91,10 +97,12 @@ impl<X: PlotNum, Y: PlotNum> SimpleTheme for Plotter<'_, X, Y> {
     }
 
     fn simple_theme_dark(&mut self, a: &mut dyn fmt::Write) -> std::fmt::Result {
+        let dim = self.get_dim();
+
         write!(
             a,
             "{}<style>{}</style>{}{}",
-            SVG_HEADER,
+            disp_const(|w| write_header(w, dim[0], dim[1])),
             STYLE_CONFIG_DARK_DEFAULT,
             disp(|a| self.render(a)),
             SVG_END
